@@ -24,16 +24,12 @@
 #define FADE_STEPS    20
 #define TIME_FRACTION 20
 
-static FadeText::Prefs *prefs=new FadeText::Prefs();
-
 FadeText::FadeText()
  : text(0),
    font(Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,300)),
    fadeStep(0),
    timerAction(new Lum::Model::Action())
 {
-  SetPrefs(::prefs);
-
   colors.resize(FADE_STEPS);
   colors[0]=Lum::OS::display->GetColor(Lum::OS::Display::backgroundColor);
   for (size_t i=1; i<FADE_STEPS; i++) {
